@@ -15,9 +15,11 @@ import (
 	"github.com/inancgumus/screen"
 	"github.com/spf13/cobra"
 
+	"github.com/superfly/flyctl/pkg/flaps"
 	"github.com/superfly/flyctl/pkg/iostreams"
 
 	"github.com/superfly/flyctl/api"
+
 	"github.com/superfly/flyctl/internal/app"
 	"github.com/superfly/flyctl/internal/client"
 	"github.com/superfly/flyctl/internal/command"
@@ -96,18 +98,19 @@ func once(ctx context.Context, out io.Writer) (err error) {
 		jsonOutput = config.FromContext(ctx).JSONOutput
 	)
 
-	app, err := client.GetApp(ctx, appName)
+	app, err := client.GetAppCompact(ctx, appName)
 	if err != nil {
 		return fmt.Errorf("failed to get app: %s", err)
 	}
 
+	platformVersion := app.PlatformVersion
+
 	var status *api.AppStatus
 	if status, err = client.GetAppStatus(ctx, appName, all); err != nil {
 		err = fmt.Errorf("failed retrieving app %s: %w", appName, err)
 
 		return
 	}
-
 	var backupRegions []api.Region
 	if status.Deployed && !jsonOutput {
 		if _, backupRegions, err = client.ListAppRegions(ctx, appName); err != nil {
@@ -134,29 +137,23 @@ func once(ctx context.Context, out io.Writer) (err error) {
 	if err = render.VerticalTable(out, "App", obj, "Name", "Owner", "Version", "Status", "Hostname"); err != nil {
 		return
 	}
-
-	if !status.Deployed && app.PlatformVersion == "" {
+	if !status.Deployed && platformVersion == "" {
 		_, err = fmt.Fprintln(out, "App has not been deployed yet.")
 
 		return
 	}
 
-	switch app.PlatformVersion {
-	case "nomad":
-		showDeploymentStatus := status.DeploymentStatus != nil &&
-			((status.DeploymentStatus.Version == status.Version && status.DeploymentStatus.Status != "cancelled") || flag.GetBool(ctx, "deployment"))
+	showDeploymentStatus := status.DeploymentStatus != nil &&
+		((status.DeploymentStatus.Version == status.Version && status.DeploymentStatus.Status != "cancelled") || flag.GetBool(ctx, "deployment"))
 
-		if showDeploymentStatus {
-			if err = renderDeploymentStatus(out, status.DeploymentStatus); err != nil {
-				return
-			}
+	if showDeploymentStatus {
+		if err = renderDeploymentStatus(out, status.DeploymentStatus); err != nil {
+			return
 		}
-
-		err = render.AllocationStatuses(out, "Instances", backupRegions, status.Allocations...)
-
-	case "machines":
-		err = render.MachineStatuses(out, "Machines", app.Machines.Nodes...)
 	}
+
+	err = render.AllocationStatuses(out, "Instances", backupRegions, status.Allocations...)
+
 	return
 }
 
@@ -223,3 +220,49 @@ func runWatch(ctx context.Context) (err error) {
 
 	return
 }
+
+func renderMachineStatus(ctx context.Context, app *api.AppCompact) (err error) {
+	io := iostreams.FromContext(ctx)
+
+	flapsClient, err := flaps.New(ctx, app)
+
+	if err != nil {
+		return err
+	}
+
+	machines, err := flapsClient.List(ctx, "")
+
+	if err != nil {
+		return err
+	}
+
+	obj := [][]string{
+		{
+			app.Name,
+			app.Organization.Slug,
+			app.Hostname,
+		},
+	}
+
+	if err = render.VerticalTable(io.Out, "App", obj, "Name", "Owner", "Hostname"); err != nil {
+		return
+	}
+
+	rows := [][]string{}
+
+	for _, machine := range machines {
+		rows = append(rows, []string{
+			machine.ID,
+			fmt.Sprintf("%s:%s", machine.ImageRef.Repository, machine.ImageRef.Tag),
+			machine.CreatedAt,
+			machine.State,
+			machine.Region,
+			machine.Name,
+			machine.PrivateIP,
+		})
+	}
+
+	_ = render.Table(io.Out, "", rows, "ID", "Image", "Created", "State", "Region", "Name", "IP Address")
+
+	return
+}
